pub enum Observation<L> {
Observed {
label: L,
count: u64,
timestamp: Instant,
},
ObservedOne {
label: L,
timestamp: Instant,
},
ObservedOneValue {
label: L,
value: ObservedValue,
timestamp: Instant,
},
}Expand description
An observation that has been made.
Be aware that not all instruments handle all
observations or values.
E.g. a Meter does not take the value of
an Observation::ObservedOneValue into account but
simply counts the observation as one occurrence.
Variants
Observed
Observed many occurrences with no value at the given timestamp
ObservedOne
Observed one occurrence without a value at the given timestamp
ObservedOneValue
Observed one occurrence with a value at a given timestamp.
Implementations
Sourceimpl<L> Observation<L>
impl<L> Observation<L>
pub fn observed(label: L, count: u64, timestamp: Instant) -> Self
pub fn observed_now(label: L, count: u64) -> Self
pub fn observed_one(label: L, timestamp: Instant) -> Self
pub fn observed_one_now(label: L) -> Self
pub fn observed_one_value<T: Into<ObservedValue>>( label: L, value: T, timestamp: Instant, ) -> Self
pub fn observed_one_value_now<T: Into<ObservedValue>>( label: L, value: T, ) -> Self
Sourceimpl<L> Observation<L>
impl<L> Observation<L>